pub struct BlockEntryV1 {
pub block_key: String,
pub reason: String,
pub source_profile_refs: Vec<String>,
pub admissible_exception_classes: Vec<String>,
}Fields
block_key: Stringreason: Stringsource_profile_refs: Vec<String>admissible_exception_classes: Vec<String>Trait Implementations
Sourceimpl Clone for BlockEntryV1
impl Clone for BlockEntryV1
Sourcefn clone(&self) -> BlockEntryV1
fn clone(&self) -> BlockEntryV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockEntryV1
impl Debug for BlockEntryV1
Sourceimpl<'de> Deserialize<'de> for BlockEntryV1
impl<'de> Deserialize<'de> for BlockEntryV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BlockEntryV1
Sourceimpl JsonSchema for BlockEntryV1
impl JsonSchema for BlockEntryV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BlockEntryV1
impl PartialEq for BlockEntryV1
Sourcefn eq(&self, other: &BlockEntryV1) -> bool
fn eq(&self, other: &BlockEntryV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BlockEntryV1
impl Serialize for BlockEntryV1
impl StructuralPartialEq for BlockEntryV1