pub struct CompiledObligationEntryV1 {
pub obligation_entry_id: String,
pub obligation_family: String,
pub obligation_key: String,
pub output_kind: CompiledObligationKindV1,
pub fold_class: FoldClassV1,
pub string_values: Vec<String>,
pub numeric_value: Option<i64>,
pub expiry_at: Option<String>,
pub blocking: bool,
pub source_profile_refs: Vec<String>,
pub source_exception_refs: Vec<ProfileExceptionBundleId>,
pub explanation: String,
}Fields
obligation_entry_id: Stringobligation_family: Stringobligation_key: Stringoutput_kind: CompiledObligationKindV1fold_class: FoldClassV1string_values: Vec<String>numeric_value: Option<i64>expiry_at: Option<String>blocking: boolsource_profile_refs: Vec<String>source_exception_refs: Vec<ProfileExceptionBundleId>explanation: StringTrait Implementations
Sourceimpl Clone for CompiledObligationEntryV1
impl Clone for CompiledObligationEntryV1
Sourcefn clone(&self) -> CompiledObligationEntryV1
fn clone(&self) -> CompiledObligationEntryV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompiledObligationEntryV1
impl Debug for CompiledObligationEntryV1
Sourceimpl<'de> Deserialize<'de> for CompiledObligationEntryV1
impl<'de> Deserialize<'de> for CompiledObligationEntryV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompiledObligationEntryV1
Sourceimpl JsonSchema for CompiledObligationEntryV1
impl JsonSchema for CompiledObligationEntryV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompiledObligationEntryV1
impl PartialEq for CompiledObligationEntryV1
Sourcefn eq(&self, other: &CompiledObligationEntryV1) -> bool
fn eq(&self, other: &CompiledObligationEntryV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for CompiledObligationEntryV1