pub struct CompiledObligationSetV1 {Show 17 fields
pub schema_version: String,
pub compiled_obligation_set_id: CompiledObligationSetId,
pub effective_constitution_ref: EffectiveConstitutionId,
pub obligation_entries: Vec<CompiledObligationEntryV1>,
pub block_entries: Vec<BlockEntryV1>,
pub required_approvals: Vec<String>,
pub required_checks: Vec<String>,
pub required_monitors: Vec<String>,
pub required_evidence_obligations: Vec<String>,
pub required_disclosure_obligations: Vec<String>,
pub required_rollback_obligations: Vec<String>,
pub required_compensation_obligations: Vec<String>,
pub required_post_hoc_review_obligations: Vec<String>,
pub promotion_eligibility_summary: String,
pub release_eligibility_summary: String,
pub effect_eligibility_summary: String,
pub unresolved_dependency_refs: Vec<String>,
}Fields
schema_version: Stringcompiled_obligation_set_id: CompiledObligationSetIdeffective_constitution_ref: EffectiveConstitutionIdobligation_entries: Vec<CompiledObligationEntryV1>block_entries: Vec<BlockEntryV1>required_approvals: Vec<String>required_checks: Vec<String>required_monitors: Vec<String>required_evidence_obligations: Vec<String>required_disclosure_obligations: Vec<String>required_rollback_obligations: Vec<String>required_compensation_obligations: Vec<String>required_post_hoc_review_obligations: Vec<String>promotion_eligibility_summary: Stringrelease_eligibility_summary: Stringeffect_eligibility_summary: Stringunresolved_dependency_refs: Vec<String>Trait Implementations
Sourceimpl Clone for CompiledObligationSetV1
impl Clone for CompiledObligationSetV1
Sourcefn clone(&self) -> CompiledObligationSetV1
fn clone(&self) -> CompiledObligationSetV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompiledObligationSetV1
impl Debug for CompiledObligationSetV1
Sourceimpl<'de> Deserialize<'de> for CompiledObligationSetV1
impl<'de> Deserialize<'de> for CompiledObligationSetV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompiledObligationSetV1
Sourceimpl JsonSchema for CompiledObligationSetV1
impl JsonSchema for CompiledObligationSetV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompiledObligationSetV1
impl PartialEq for CompiledObligationSetV1
Sourcefn eq(&self, other: &CompiledObligationSetV1) -> bool
fn eq(&self, other: &CompiledObligationSetV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompiledObligationSetV1
impl Serialize for CompiledObligationSetV1
impl StructuralPartialEq for CompiledObligationSetV1