pub struct CompositionConflictSetV1 {
pub schema_version: String,
pub composition_conflict_set_id: CompositionConflictSetId,
pub effective_constitution_ref: Option<EffectiveConstitutionId>,
pub composition_receipt_ref: Option<CompositionReceiptId>,
pub conflicts: Vec<CompositionConflictV1>,
pub blocking: bool,
}Fields
schema_version: Stringcomposition_conflict_set_id: CompositionConflictSetIdeffective_constitution_ref: Option<EffectiveConstitutionId>composition_receipt_ref: Option<CompositionReceiptId>conflicts: Vec<CompositionConflictV1>blocking: boolTrait Implementations
Sourceimpl Clone for CompositionConflictSetV1
impl Clone for CompositionConflictSetV1
Sourcefn clone(&self) -> CompositionConflictSetV1
fn clone(&self) -> CompositionConflictSetV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompositionConflictSetV1
impl Debug for CompositionConflictSetV1
Sourceimpl<'de> Deserialize<'de> for CompositionConflictSetV1
impl<'de> Deserialize<'de> for CompositionConflictSetV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompositionConflictSetV1
Sourceimpl JsonSchema for CompositionConflictSetV1
impl JsonSchema for CompositionConflictSetV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompositionConflictSetV1
impl PartialEq for CompositionConflictSetV1
Sourcefn eq(&self, other: &CompositionConflictSetV1) -> bool
fn eq(&self, other: &CompositionConflictSetV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompositionConflictSetV1
impl Serialize for CompositionConflictSetV1
impl StructuralPartialEq for CompositionConflictSetV1