pub struct CompositionConflictV1 {
pub obligation_family: String,
pub obligation_key: String,
pub conflict_class: String,
pub blocking: bool,
pub source_profile_refs: Vec<String>,
pub implicated_values: Vec<String>,
pub admissible_exception_classes: Vec<String>,
pub review_path: String,
pub explanation: String,
}Fields
obligation_family: Stringobligation_key: Stringconflict_class: Stringblocking: boolsource_profile_refs: Vec<String>implicated_values: Vec<String>admissible_exception_classes: Vec<String>review_path: Stringexplanation: StringTrait Implementations
Sourceimpl Clone for CompositionConflictV1
impl Clone for CompositionConflictV1
Sourcefn clone(&self) -> CompositionConflictV1
fn clone(&self) -> CompositionConflictV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompositionConflictV1
impl Debug for CompositionConflictV1
Sourceimpl<'de> Deserialize<'de> for CompositionConflictV1
impl<'de> Deserialize<'de> for CompositionConflictV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompositionConflictV1
Sourceimpl JsonSchema for CompositionConflictV1
impl JsonSchema for CompositionConflictV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompositionConflictV1
impl PartialEq for CompositionConflictV1
Sourcefn eq(&self, other: &CompositionConflictV1) -> bool
fn eq(&self, other: &CompositionConflictV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompositionConflictV1
impl Serialize for CompositionConflictV1
impl StructuralPartialEq for CompositionConflictV1