pub struct CompositionReceiptV1 {Show 13 fields
pub schema_version: String,
pub composition_receipt_id: CompositionReceiptId,
pub applicability_context_ref: ApplicabilityContextId,
pub profile_set_ref: ProfileSetId,
pub composition_rule_set_ref: CompositionRuleSetId,
pub effective_constitution_ref: Option<EffectiveConstitutionId>,
pub compiled_obligation_set_ref: Option<CompiledObligationSetId>,
pub composition_conflict_set_ref: Option<CompositionConflictSetId>,
pub degradation_markers: Vec<String>,
pub execution_context_ref: Option<String>,
pub replay_handle: String,
pub normalized_input_digest: ContentDigest,
pub generated_at: String,
}Fields
schema_version: Stringcomposition_receipt_id: CompositionReceiptIdapplicability_context_ref: ApplicabilityContextIdprofile_set_ref: ProfileSetIdcomposition_rule_set_ref: CompositionRuleSetIdeffective_constitution_ref: Option<EffectiveConstitutionId>compiled_obligation_set_ref: Option<CompiledObligationSetId>composition_conflict_set_ref: Option<CompositionConflictSetId>degradation_markers: Vec<String>execution_context_ref: Option<String>replay_handle: Stringnormalized_input_digest: ContentDigestgenerated_at: StringTrait Implementations
Sourceimpl Clone for CompositionReceiptV1
impl Clone for CompositionReceiptV1
Sourcefn clone(&self) -> CompositionReceiptV1
fn clone(&self) -> CompositionReceiptV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CompositionReceiptV1
impl Debug for CompositionReceiptV1
Sourceimpl<'de> Deserialize<'de> for CompositionReceiptV1
impl<'de> Deserialize<'de> for CompositionReceiptV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CompositionReceiptV1
Sourceimpl JsonSchema for CompositionReceiptV1
impl JsonSchema for CompositionReceiptV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CompositionReceiptV1
impl PartialEq for CompositionReceiptV1
Sourcefn eq(&self, other: &CompositionReceiptV1) -> bool
fn eq(&self, other: &CompositionReceiptV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CompositionReceiptV1
impl Serialize for CompositionReceiptV1
impl StructuralPartialEq for CompositionReceiptV1