pub struct PolicyImpactDiffV1 {Show 16 fields
pub schema_version: String,
pub policy_impact_diff_id: PolicyImpactDiffId,
pub from_effective_constitution_ref: EffectiveConstitutionId,
pub to_effective_constitution_ref: EffectiveConstitutionId,
pub changed_obligation_families: Vec<String>,
pub unchanged_obligation_families: Vec<String>,
pub newly_blocked_paths: Vec<String>,
pub newly_admitted_paths: Vec<String>,
pub changed_approval_behavior: Vec<String>,
pub changed_monitoring_behavior: Vec<String>,
pub changed_disclosure_behavior: Vec<String>,
pub changed_residency_behavior: Vec<String>,
pub changed_incident_behavior: Vec<String>,
pub migration_consequences: Vec<String>,
pub simulation_only: bool,
pub explanation_summary: String,
}Fields
schema_version: Stringpolicy_impact_diff_id: PolicyImpactDiffIdfrom_effective_constitution_ref: EffectiveConstitutionIdto_effective_constitution_ref: EffectiveConstitutionIdchanged_obligation_families: Vec<String>unchanged_obligation_families: Vec<String>newly_blocked_paths: Vec<String>newly_admitted_paths: Vec<String>changed_approval_behavior: Vec<String>changed_monitoring_behavior: Vec<String>changed_disclosure_behavior: Vec<String>changed_residency_behavior: Vec<String>changed_incident_behavior: Vec<String>migration_consequences: Vec<String>simulation_only: boolexplanation_summary: StringTrait Implementations
Sourceimpl Clone for PolicyImpactDiffV1
impl Clone for PolicyImpactDiffV1
Sourcefn clone(&self) -> PolicyImpactDiffV1
fn clone(&self) -> PolicyImpactDiffV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PolicyImpactDiffV1
impl Debug for PolicyImpactDiffV1
Sourceimpl<'de> Deserialize<'de> for PolicyImpactDiffV1
impl<'de> Deserialize<'de> for PolicyImpactDiffV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PolicyImpactDiffV1
Sourceimpl JsonSchema for PolicyImpactDiffV1
impl JsonSchema for PolicyImpactDiffV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PolicyImpactDiffV1
impl PartialEq for PolicyImpactDiffV1
Sourcefn eq(&self, other: &PolicyImpactDiffV1) -> bool
fn eq(&self, other: &PolicyImpactDiffV1) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PolicyImpactDiffV1
impl Serialize for PolicyImpactDiffV1
impl StructuralPartialEq for PolicyImpactDiffV1