pub struct ProfileSetV1 {
pub schema_version: String,
pub profile_set_id: ProfileSetId,
pub applicability_context_ref: ApplicabilityContextId,
pub profile_refs: ProfileRefGroupV1,
pub source_admission_refs: Vec<String>,
pub omissions: Vec<ProfileOmissionV1>,
pub active_exception_refs: Vec<ProfileExceptionBundleId>,
pub normalized_profile_order: Vec<String>,
}Fields
schema_version: Stringprofile_set_id: ProfileSetIdapplicability_context_ref: ApplicabilityContextIdprofile_refs: ProfileRefGroupV1source_admission_refs: Vec<String>omissions: Vec<ProfileOmissionV1>active_exception_refs: Vec<ProfileExceptionBundleId>normalized_profile_order: Vec<String>Implementations
Sourceimpl ProfileSetV1
impl ProfileSetV1
Sourcepub fn new(
applicability_context_ref: ApplicabilityContextId,
profile_refs: ProfileRefGroupV1,
source_admission_refs: Vec<String>,
) -> Self
pub fn new( applicability_context_ref: ApplicabilityContextId, profile_refs: ProfileRefGroupV1, source_admission_refs: Vec<String>, ) -> Self
Creates a profile set and captures its initial normalized profile ordering.
Sourcepub fn refresh_normalized_profile_order(&mut self)
pub fn refresh_normalized_profile_order(&mut self)
Recomputes the normalized profile ordering after in-memory edits.
Sourcepub fn all_profile_refs(&self) -> Vec<String>
pub fn all_profile_refs(&self) -> Vec<String>
Returns the deduplicated profile references visible through this set.