pub struct ExceptionAdmissibilityRuleV1 {
pub exception_class: String,
pub allowed_obligation_families: Vec<String>,
pub requires_approval_refs: bool,
pub requires_expiry: bool,
pub residual_obligations_mandatory: bool,
}Fields
exception_class: Stringallowed_obligation_families: Vec<String>requires_approval_refs: boolrequires_expiry: boolresidual_obligations_mandatory: boolTrait Implementations
Sourceimpl Clone for ExceptionAdmissibilityRuleV1
impl Clone for ExceptionAdmissibilityRuleV1
Sourcefn clone(&self) -> ExceptionAdmissibilityRuleV1
fn clone(&self) -> ExceptionAdmissibilityRuleV1
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExceptionAdmissibilityRuleV1
impl Debug for ExceptionAdmissibilityRuleV1
Sourceimpl<'de> Deserialize<'de> for ExceptionAdmissibilityRuleV1
impl<'de> Deserialize<'de> for ExceptionAdmissibilityRuleV1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ExceptionAdmissibilityRuleV1
Sourceimpl JsonSchema for ExceptionAdmissibilityRuleV1
impl JsonSchema for ExceptionAdmissibilityRuleV1
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExceptionAdmissibilityRuleV1
impl PartialEq for ExceptionAdmissibilityRuleV1
Sourcefn eq(&self, other: &ExceptionAdmissibilityRuleV1) -> bool
fn eq(&self, other: &ExceptionAdmissibilityRuleV1) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ExceptionAdmissibilityRuleV1